@@ -204,7 +204,9 @@ class AstroData():
         g1 /= np.sqrt(np.pi/4/np.log(2) * bmin * np.sqrt(1 - bmin**2/bmaj**2))
         g = np.zeros((ny, nx))
         g[:, (nx - 1) // 2] = g1
-        d = to4dim(self.data)
+        d = self.data.copy()
+        d[np.isnan(d)] = 0
+        d = to4dim(d)
         d = [[convolve(c, g, mode='same') for c in cc] for cc in d]
         self.data = np.squeeze(d)
         self.rotate(bpa)
@@ -650,7 +652,7 @@ class AstroFrame():
         for i in range(d.n):
             if d.center[i] == 'common':
                 d.center[i] = self.center
-            grid = grid0
+            grid = grid0.copy()
             if d.fitsimage[i] is not None:
                 fd = FitsData(d.fitsimage[i])
                 if d.fitsheader[i] is None:
@@ -676,6 +678,15 @@ class AstroFrame():
             if d.data[i] is not None:
                 d.sigma_org[i] = d.sigma[i]
                 d.sigma[i] = estimate_rms(d.data[i], d.sigma[i])
+                diffcent = (not self.pv
+                            and self.center is not None
+                            and d.center[i] is not None
+                            and d.center[i] != self.center)
+                if diffcent:
+                    cx, cy = coord2xy(d.center[i], self.center) * 3600
+                    grid[0] = grid[0] + cx  # Don't use += cx.
+                    grid[1] = grid[1] + cy  # Don't use += cy.
+                    d.center[i] = self.center
                 d.data[i], grid = trim(data=d.data[i],
                                        x=grid[0], y=grid[1], v=grid[2],
                                        xlim=self.xlim, ylim=self.ylim,
